#                   网络IP学习

## IP地址、网关和子网掩码

### 一、IP地址

IP地址（Internet Protocol Address）是指“互联网”协议地址，又译为网际协议地址。IP地址是IP协议提供的一种统一的“地址格式”，它为互联网上的每一个网络和每一台主机分配一个“逻辑地址”，以此来屏蔽“物理地址”的差异。

IP协议是为计算机网络相互连接进行通信而设计的协议。IP协议实际上是一套由软件程序组成的协议软件，它把各种不同“帧”统一转换成“IP数据报”格式，这种转换是因特网的一个最重要的特点，使所有各种计算机都能在因特网上实现互通，即具有“开放性”的特点。正是因为有了IP协议，因特网才得以迅速发展成为世界上最大的、开放的计算机通信网络。因此，IP协议也可以叫做“因特网协议”。

IP地址分为网络部分（属于哪一网段）和主机部分（属于网段下哪一主机）。有32个二进制位组成，通常被分割为4个“8位二进制数”。IP地址通常用“点十分进制”（a.b.c.d）形式表示。其中，a,b,c,d都是0~255之间的十进制整数。例：点分十进IP地址（100.4.5.6），实际上是32位二进制数（01100100.00000100.00000101.00000110）。

#### 1、IP地址类型

##### 公有地址

公有地址（Public address）由Inter NIC（Internet Network Information Center因特网信息中心）负责。这些IP地址分配给注册并向Inter NIC提出申请的组织机构。通过它直接访问因特网。

##### 私有地址

私有地址（Private address）属于非注册地址，专门为组织机构内部使用。

以下列出留用的内部私有地址

A类 10.0.0.0--10.255.255.255

B类 172.16.0.0--172.31.255.255

C类 192.168.0.0--192.168.255.255

#### 2、IP地址编址方式

最初设计互联网络时，为了便于寻址以及层次化构造网络，每个IP地址包括两个标识码（ID），即网络ID和主机ID。同一个物理网络上的所有主机都使用同一个网络ID，网络上的一个主机（包括网络上工作站，服务器和路由器等）有一个主机ID与其对应。Internet委员会定义了5种IP地址类型以适合不同容量的网络，即A类~E类。其中A、B、C3类由InternetNIC在全球范围内统一分配，D、E类为特殊地址。

#### 3、特殊的网址

1. 每一个字节都为0的地址（“0.0.0.0”）对应于当前主机；
2. IP地址中的每一个字节都为1的IP地址（“255．255．255．255”）是当前子网的广播地址；
3. IP地址中凡是以“11110”开头的E类IP地址都保留用于将来和实验使用。
4. IP地址中不能以十进制“127”作为开头，该类地址中数字127.0.0.1到127.255.255.255用于回路测试，如：127.0.0.1可以代表本机IP地址，用“http://127.0.0.1”就可以测试本机中配置的Web服务器。
5. 网络ID的第一个6位组也不能全置为“0”，全“0”表示本地网络。

### 二、网关

网关(Gateway)又称[网间连接器](https://baike.baidu.com/item/网间连接器/2943752)、[协议转换](https://baike.baidu.com/item/协议转换)器。网关在[网络层](https://baike.baidu.com/item/网络层/4329439)以上实现[网络互连](https://baike.baidu.com/item/网络互连/108997)，是复杂的网络互连设备，仅用于两个高层协议不同的[网络互连](https://baike.baidu.com/item/网络互连/108997)。网关既可以用于[广域网](https://baike.baidu.com/item/广域网/422004)互连，也可以用于[局域网](https://baike.baidu.com/item/局域网)互连。 网关是一种充当转换重任的[计算机系统](https://baike.baidu.com/item/计算机系统/7210959)或设备。使用在不同的[通信协议](https://baike.baidu.com/item/通信协议/3351624)、数据格式或语言，甚至[体系结构](https://baike.baidu.com/item/体系结构/8174145)完全不同的两种系统之间，网关是一个[翻译器](https://baike.baidu.com/item/翻译器/2677454)。与[网桥](https://baike.baidu.com/item/网桥/99310)只是简单地传达信息不同，网关对收到的信息要重新打包，以适应目的系统的需求。同层--应用层。

#### 1、设置

##### 手动

手动设置适用于电脑数量比较少、[TCP](https://baike.baidu.com/item/TCP/33012)/IP参数基本不变的情况，比如只有几台到十几台电脑。因为这种方法需要在联入网络的每台电脑上设置“[默认网关](https://baike.baidu.com/item/默认网关)”，非常费劲，一旦因为迁移等原因导致必须修改默认网关的IP地址，就会给网关带来很大的麻烦，所以不推荐使用。

在Windows 7中，设置[默认网关](https://baike.baidu.com/item/默认网关)的方法是在“[网上邻居](https://baike.baidu.com/item/网上邻居)”上右击，在弹出的菜单中点击“属性”，在网络属性对话框中选择“[TCP/IP协议](https://baike.baidu.com/item/TCP%2FIP协议/212915)”，点击“属性”，在“默认网关”选项卡中填写新的默认网关的IP地址就可以了。

需要特别注意的是：[默认网关](https://baike.baidu.com/item/默认网关)必须是电脑自己所在的[网段](https://baike.baidu.com/item/网段)中的IP地址，而不能填写其他网段中的IP地址。

##### 自动

自动设置就是利用[DHCP服务器](https://baike.baidu.com/item/DHCP服务器)来自动给网络中的电脑分配IP地址、[子网掩码](https://baike.baidu.com/item/子网掩码)和[默认网关](https://baike.baidu.com/item/默认网关)。这样做的好处是一旦网络的[默认网关](https://baike.baidu.com/item/默认网关)发生了变化时，只要更改了[DHCP服务器](https://baike.baidu.com/item/DHCP服务器/9956953)中默认网关的设置，那么网络中所有的电脑均获得了新的默认网关的IP地址。这种方法适用于网络规模较大、TCP/IP参数有可能变动的网络。

另外一种自动获得网关的办法是通过安装[代理服务器](https://baike.baidu.com/item/代理服务器)[软件](https://baike.baidu.com/item/软件)（如MS Proxy）的客户端程序来自动获得，其原理和方法和DHCP有相似之处。

### 三、子网掩码

子网掩码(subnet mask)又叫[网络掩码](https://baike.baidu.com/item/网络掩码/7862514)、[地址掩码](https://baike.baidu.com/item/地址掩码/8623995)、子网络遮罩，它用来指明一个[IP地址](https://baike.baidu.com/item/IP地址)的哪些位标识的是[主机](https://baike.baidu.com/item/主机/455151)所在的子网，以及哪些位标识的是主机的位掩码。子网掩码不能单独存在，它必须结合IP地址一起使用。子网掩码只有一个作用，就是将某个IP地址划分成网络地址和主机地址两部分。

子网掩码是一个32位地址，用于屏蔽IP地址的一部分以区别网络标识和主机标识，并说明该IP地址是在[局域网](https://baike.baidu.com/item/局域网/98626)上，还是在[广域网](https://baike.baidu.com/item/广域网/422004)上。

例如：IP地址192.168.1.1和255.255.255.0。255.255.255.0就是192.168.1.1的子网掩码。

#### 1、功能

子网掩码是一个32位地址，是与IP地址结合使用的一种技术。它的主要作用有两个，一是用于屏蔽IP地址的一部分以区别网络标识和主机标识，并说明该IP地址是在局域网上，还是在远程网上。二是用于将一个大的IP网络划分为若干小的子网络。

使用子网是为了减少IP的浪费。因为随着互联网的发展，越来越多的网络产生，有的网络多则几百台，有的只有区区几台，这样就浪费了很多IP地址，所以要划分子网。使用子网可以提高网络应用的效率。

通过计算机的子网掩码判断两台计算机是否属于同一网段的方法是，将计算机十进制的IP地址和子网掩码转换为二进制的形式，然后进行二进制“与”(AND)计算（全1则得1，不全1则得0），如果得出的结果是相同的，那么这两台计算机就属于同一网段。

#### 2、网络地址与主机地址

子网掩码一定是配合IP地址来使用的。对于常用网络A、 B、C 类IP地址其默认子网掩码的二进制与十进制对应关系如表1所示。子网掩码工作过程是：将32位的子网掩码与IP地址进行“二进制”形式的按位逻辑与运算得到的便是网络地址，将子网掩码二进制和IP地址二进制进行逻辑“与”（AND）运算，得到的就是主机地址。如：192.168.10.11 AND 255.255.255.0，结果为192.168.10.0，其表达的含义为：该IP地址属于 192.168.10.0这个网络，其主机号为11，即这个网络中编号为11的主机。

#### 3、计算

由于子网掩码的位数决定于可能的子网数目和每个子网的主机数目。在定义子网掩码前，必须弄清楚本来使用的子网数和主机数目。

##### （子网掩码其计算方式不理解）（此次学习内容学习的只是潜在易理解的，深入的内容没有进行学习因为是实在不理解）以上内容是学生对网络IP学习内容的理解。